@@ -54,7 +54,7 @@ from TestCommon import __all__, _python_
 # here provides some independent verification that what we packaged
 # conforms to what we expect.
 
-default_version = '4.9.1'
+default_version = '4.9.2ayyyymmdd'
 
 # TODO: these need to be hand-edited when there are changes
 python_version_unsupported = (3, 7, 0)
@@ -1724,7 +1724,15 @@ SConscript(sconscript)
 
         Returns a path to a Python executable suitable for testing on
         this platform and its associated include path, library path and
-        library name.
+        library name. ``runtest.py`` sets an environment variable with the
+        desired Python path, so if we're started from there, use that.
+
+        This exists because of SWIG, which may need to build things against
+        the Python header and library.  The approach is a bit of a large
+        hammer: we run a script like we would a test, and capture the results,
+        rather than querying the running Python. This supports the test
+        runner's ``-P`` option to specify an alternate Python, otherwise
+        we wouldn't need to be this complex.
 
         If the Python executable or Python header (if required)
         is not found, the test is skipped.
@@ -1732,7 +1740,7 @@ SConscript(sconscript)
         Returns:
             tuple: path to python, include path, library path, library name
         """
-        python = os.environ.get('python_executable', self.where_is('python'))
+        python = os.environ.get('python_executable', sys.executable)
         if not python:
             self.skip_test(
                 'Can not find installed "python", skipping test.\n', from_fw=True
@@ -1823,9 +1831,17 @@ else:
             restore_sconsflags(sconsflags)
         return p
 
-    def wait_for(self, fname, timeout: float = 20.0, popen=None) -> None:
-        """
-        Waits for the specified file name to exist.
+    def wait_for(self, fname, timeout: float = 20.0, popen=None):
+        """Wait for the specified file name to exist.
+
+        This interface is primarily used in the tests for interactive
+        mode, where you issue individual commands and SCons keeps running.
+
+        Wait up to *timeout* seconds for *fname* to exist.  If the
+        timeout is reached, fail the test. If *popen* is specified,
+        it is assumed to be a process started with the :meth:`start`
+        method, giving a handle to cleanup actions.
+
         """
         waited = 0.0
         while not os.path.exists(fname):
@@ -1846,7 +1862,7 @@ else:
                     sys.stderr.write(stderr)
                 self.fail_test()
             time.sleep(1.0)
-            waited = waited + 1.0
+            waited += 1.0
 
     def get_alt_cpp_suffix(self):
         """Return alternate C++ file suffix.
